import os
import pandas as pd
from pptx import Presentation

def replace_seq_in_runs_for_each_sheet(excel_file, template_pptx):
    """
    Excelファイル内の全シートについて、
    A列(SEQ)→E列(アイデアの詳細)のマッピングでパワーポイントを置換し、
    シート名.pptx として出力するサンプル。
    """

    # Excelに含まれるすべてのシートを確認
    # pandasのExcelFileオブジェクトを使うとシート名の一覧を取得しやすい
    xls = pd.ExcelFile(excel_file, engine="openpyxl")
    sheet_names = xls.sheet_names  # ["Sheet1", "Sheet2", ...]

    for sheet_name in sheet_names:
        # --- 1) 該当シートのデータを読み込み ---
        df = pd.read_excel(excel_file, sheet_name=sheet_name, engine="openpyxl")

        # もし「A列=SEQ」「E列=アイデアの詳細」が無い場合はスキップ or 警告
        required_cols = {"SEQ", "アイデアの詳細"}
        if not required_cols.issubset(df.columns):
            print(f"シート '{sheet_name}' に必要な列 {required_cols} がありません。スキップします。")
            continue

        # A列→E列のマッピングを辞書にする
        seq_dict = {}
        for _, row in df.iterrows():
            seq_key = str(row["SEQ"])
            seq_val = str(row["アイデアの詳細"])

            # "<br>" を "\n" に置換しておく
            seq_val = seq_val.replace("<br>", "\n")

            seq_dict[seq_key] = seq_val

        # --- 2) テンプレートPPTXを読み込み ---
        prs = Presentation(template_pptx)

        # --- 3) 全スライド・全シェイプのテキストをラン単位で置換 ---
        for slide in prs.slides:
            for shape in slide.shapes:
                if not shape.has_text_frame:
                    continue
                for paragraph in shape.text_frame.paragraphs:
                    for run in paragraph.runs:
                        old_text = run.text
                        new_text = old_text
                        # seq_dict のキーを部分置換
                        for seq_key, seq_val in seq_dict.items():
                            if seq_key in new_text:
                                new_text = new_text.replace(seq_key, seq_val)
                        if new_text != old_text:
                            run.text = new_text

        # --- 4) ファイル名を「シート名.pptx」にして保存 ---
        output_filename = f"{sheet_name}.pptx"
        prs.save(output_filename)
        print(f"[DONE] '{output_filename}' を作成しました。")

if __name__ == "__main__":
    BASE_DIR         = os.path.dirname(os.path.abspath(__file__))  # スクリプトがあるフォルダの絶対パス
    template_pptx    = os.path.join(BASE_DIR, "..", "template", "template.pptx")
    excel_file       = os.path.join(BASE_DIR, "..", "template", "input_data.xlsx")
    if not os.path.exists(template_pptx):
        print(f"テンプレートのパワーポイントが見つかりません: {template_pptx}")
    elif not os.path.exists(excel_file):
        print(f"データのエクセルが見つかりません: {excel_file}")
    else:
        replace_seq_in_runs_for_each_sheet(excel_file, template_pptx)
